autowisp.database.data_model.provenance.telescope_type module — AutoWISP documentation

# autowisp.database.data_model.provenance.telescope_type module

## Class Inheritance Diagram

Define the telescope type dataset table for the pipeline

class autowisp.database.data_model.provenance.telescope_type.TelescopeType(**kwargs)

  Bases: `DataModelBase`

  The table dscribing the different telescope types

  f_ratio

    The focal ratio of the telescope

  focal_length

    The focal length of the telescope in mm

  id

    A unique identifier for each row.

  make

    The make of the telescope

  model

    The model of the telescope

  notes

    The notes provided for the telescope type

  telescopes
  timestamp

    When record was last changed

  version

    The version of the telescope